@@ -1,17 +1,15 @@
 __docformat__ = 'google'
 
 import icepool
-from icepool.counts import Counts
+from icepool.collections import Counts
 from icepool.typing import Outcome
 
 import itertools
 import math
 from collections import defaultdict
 
-from typing import Any, Callable, Iterable, Mapping, MutableMapping, Sequence, TypeAlias, TypeVar
-
-T = TypeVar('T', bound=Outcome)
-"""Type variable representing the outcome type."""
+from icepool.typing import T
+from typing import Any, Iterable, Mapping, MutableMapping, Sequence
 
 
 def itemize(keys: Mapping[Any, int] | Sequence,
