@@ -2,8 +2,8 @@ __docformat__ = 'google'
 
 from collections import defaultdict
 import icepool
-from icepool.counts import CountsKeysView, CountsValuesView, CountsItemsView
-from icepool.typing import Outcome
+from icepool.collections import CountsKeysView, CountsValuesView, CountsItemsView
+from icepool.typing import Outcome, T_co
 
 from abc import ABC, abstractmethod
 import bisect
@@ -16,9 +16,6 @@ import random
 
 from typing import Any, Callable, Generic, Hashable, Mapping, MutableMapping, Sequence, TypeVar, overload
 
-T_co = TypeVar('T_co', bound=Outcome, covariant=True)
-"""Type variable respresenting the outcome type."""
-
 C = TypeVar('C', bound='Population')
 """Type variable representing a subclass of `Population`."""
 
@@ -34,6 +31,7 @@ class Population(ABC, Generic[T_co], Mapping[Any, int]):
 
     # Abstract methods.
 
+    @property
     @abstractmethod
     def _new_type(self) -> type:
         """The type to use when constructing a new instance."""
@@ -419,7 +417,7 @@ class Population(ABC, Generic[T_co], Mapping[Any, int]):
         for outcome, quantity in self.items():
             new_outcome = op(outcome, *args, **kwargs)
             data[new_outcome] += quantity
-        return self._new_type()(data)
+        return self._new_type(data)
 
     def covariance(self: 'Population[tuple[numbers.Real, ...]]', i: int,
                    j: int) -> float:
